@@ -13,13 +13,19 @@ class Position:
     x: float
     y: float
 
+    def __hash__(self):
+        return hash((self.x, self.y))
+
 
 @dataclass
 class Object:
     """Represents an object."""
 
     name: str
+    class_id: int
+    object_id: int
     instance_id: int
+    index: int
     position: Position
 
 
@@ -30,7 +36,9 @@ class Player:
     number: int
     name: str
     color: str
+    color_id: int
     civilization: str
+    civilization_id: int
     position: Position
     objects: list
     profile_id: int
@@ -55,12 +63,25 @@ class Action:
     position: Position = None
 
 
+@dataclass
+class Input:
+    """Represents a player input."""
+
+    timestamp: timedelta
+    type: str
+    param: str
+    payload: dict
+    player: Player = None
+    position: Position = None
+
+
 @dataclass
 class Viewlock:
     """Represents player view."""
 
     timestamp: timedelta
     position: Position
+    player: Player
 
 
 @dataclass
@@ -76,11 +97,14 @@ class Tile:
 class Map:
     """Represents a map."""
 
+    id: int
     name: str
     dimension: int
     size: str
     custom: bool
     seed: int
+    zr: bool
+    modes: dict
     tiles: list
 
     def __repr__(self):
@@ -92,6 +116,8 @@ class File:
 
     encoding: str
     language: str
+    hash: str
+    size: int
     perspective: Player
     viewlocks: list
 
@@ -102,6 +128,8 @@ class Chat:
 
     timestamp: timedelta
     message: str
+    origination: str
+    audience: str
     player: Player
 
     def __repr__(self):
@@ -118,6 +146,7 @@ class Match:
     map: Map
     file: File
     speed: str
+    speed_id: int
     cheats: bool
     lock_teams: bool
     population: int
@@ -126,8 +155,24 @@ class Match:
     lobby: str
     dataset: str
     type: str
+    type_id: int
     map_reveal: str
+    map_reveal_id: int
+    difficulty: str
+    difficulty_id: int
+    starting_age: str
+    starting_age_id: int
+    team_together: bool
+    lock_speed: bool
+    all_technologies: bool
+    multiqueue: bool
     duration: timedelta
     diplomacy_type: str
+    completed: bool
     version: Version
+    game_version: str
+    save_version: float
+    log_version: int
+    hash: str
     actions: list
+    inputs: list
